@@ -1,6 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
 # Copyright (C) 2009-2020, Roland van Ipenburg
-package HTML::Hyphenate v1.1.4;
+package HTML::Hyphenate v1.1.5;
 use Moose;
 use utf8;
 use 5.016000;
@@ -293,7 +293,7 @@ HTML::Hyphenate - insert soft hyphens into HTML.
 
 =head1 VERSION
 
-This document describes HTML::Hyphenate version v1.1.4.
+This document describes HTML::Hyphenate version v1.1.5.
 
 =head1 SYNOPSIS
 
@@ -410,13 +410,9 @@ The output is generated by L<Mojo::DOM|Mojo::DOM>.
 
 =head1 INCOMPATIBILITIES
 
-=over 4
-
 This module has the same limits as TeX::Hyphen, TeX::Hyphen::Pattern and
 Mojo::DOM.
 
-=back
-
 =head1 DIAGNOSTICS
 
 This module uses Log::Log4perl for logging.
@@ -436,11 +432,11 @@ TeX::Hyphen::Pattern
 hyphen somewhere in a word, and sometimes requires semantics to get it right.
 For example C<cafeetje> should be hyphenated as C<cafe-tje> and not
 C<cafee-tje> and C<buurtje> can be hyphenated as C<buur-tje> or C<buurt-je>,
-depending on it's meaning. While HTML could provide a bit more context (mainly
-the language being used) than plain text to handle these issues, the initial
-purpose of this module is to make it possible for HTML rendering engines that
-support soft hyphens to be able to break long words over multiple lines to
-avoid unwanted overflow.
+depending on it's meaning. While HTML could provide a bit more context –
+mainly the language being used – than plain text to handle these issues, the
+initial purpose of this module is to make it possible for HTML rendering
+engines that support soft hyphens to be able to break long words over multiple
+lines to avoid unwanted overflow.
 
 =item * The hyphenation doesn't get better than TeX::Hyphenate and it's
 hyphenation patterns provide.
